[![PyPI version](https://badge.fury.io/py/qtwirl.svg)](https://badge.fury.io/py/qtwirl) [![Build Status](https://travis-ci.org/alphatwirl/qtwirl.svg?branch=master)](https://travis-ci.org/alphatwirl/qtwirl) [![codecov](https://codecov.io/gh/alphatwirl/qtwirl/branch/master/graph/badge.svg)](https://codecov.io/gh/alphatwirl/qtwirl)

# qtwirl

qtwirl (quick-twirl), one-function interface to [AlphaTwirl](https://github.com/alphatwirl/alphatwirl)

***

### Quick start

- Jupyter Notebook: [*Quick start of AlphaTwirl with qtwirl*](https://github.com/alphatwirl/notebook-tutorial-2018-08/blob/master/tutorial_01.ipynb)<br />

&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;[<img src="https://swanserver.web.cern.ch/swanserver/images/badge_swan_white_150.png" width="150">](https://cern.ch/swanserver/cgi-bin/go?projurl=https://github.com/alphatwirl/notebook-tutorial-2018-08.git)

***
